ToExtentTensorOperation

Struct ToExtentTensorOperation 

pub struct ToExtentTensorOperation<'c> { /* private fields */ }
A to_extent_tensor operation. Creates a dimension tensor from a shape.

Converts a shape to a 1D integral tensor of extents. The number of elements in the tensor equals the rank of the shape, and the elements equal the extents of the shape.

If the shape represents an error, this op’s behavior is undefined.

Implementations

Source

impl<'c> ToExtentTensorOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> ToExtentTensorOperationBuilder<'c, Unset, Unset>

Creates a builder.

pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn input(&self) -> Result<Value<'c, '_>, Error>